@@ -20,7 +20,10 @@ class DatabaseTestCase(unittest.TestCase):
 
     def tearDown(self):
         transaction.abort()
+        meta.Session.remove()
         if self.create_tables:
             meta.metadata.drop_all()
+        meta.Session.configure(bind=None)
+        meta.metadata.bind = None
         self.engine.dispose()
         super(DatabaseTestCase, self).tearDown()
