@@ -11,7 +11,7 @@ class test_init_sqlalchemy(unittest.TestCase):
         from s4u.sqlalchemy import meta
         engine = create_engine('sqlite://')
         self.init_sqlalchemy(engine)
-        self.assertTrue(meta.Session.bind is engine)
+        self.assertTrue(meta.Session.session_factory.kw['bind'] is engine)
 
 
 class includeme_tests(unittest.TestCase):
@@ -20,6 +20,7 @@ class includeme_tests(unittest.TestCase):
         return includeme(*a, **kw)
 
     def test_sqlite_config(self):
+        import mock
         from s4u.sqlalchemy import meta
 
         class Registry:
@@ -29,5 +30,8 @@ class includeme_tests(unittest.TestCase):
             registry = Registry
 
         config = Config()
-        self.includeme(config)
-        self.assertEqual(str(meta.Session.bind.url), 'sqlite://')
+        with mock.patch('s4u.sqlalchemy.init_sqlalchemy') as init_sqlalchemy:
+            self.includeme(config)
+            self.assertTrue(init_sqlalchemy.called)
+            engine = init_sqlalchemy.mock_calls[0][1][0]
+            self.assertEqual(str(engine.url), 'sqlite://')
